==> xcxcreatepath-1.1.2.tgz: package/commands/wxpath.js <==
#!/usr/bin/env node

const path = require('path')
const fs = require('fs')
const minimist = require('minimist')
const getTmp = require('../libs/getTemplate')
const args = minimist(process.argv.slice(2))
console.log('args:', args)
if (args.o && typeof args.o == 'string') {
  let dirPath = ''

  const currentPath = path.resolve()
  if (!args.o.match('^((/[a-zA-Z0-9-_]+)+|/)$')) {
    console.log('路径输入错误 格式:/pages/list/list/')
    return;
  }
  const pagePath = args.o

  if (pagePath[0] === '/') {
    dirPath = currentPath + path.dirname(pagePath)
  } else {
    dirPath = currentPath + '/' + path.dirname(pagePath)
  }
  const fileName = path.basename(pagePath);
  console.log('fileName:', fileName)

  console.log('dirPath:', dirPath)
  if (!fs.existsSync(dirPath)) {
    mkdirsSync(dirPath) // 创建目录

    let wxssContent = getTmp.getTemplate('wechat.wxss')
    // console.log('wxssContent:', wxssContent)
    fs.writeFileSync(path.join(dirPath, `${fileName}.wxss`), `/*${pagePath}.wsss*/\n${wxssContent}`);

    let jsContent = getTmp.getTemplate('wechat.js')
    fs.writeFileSync(path.join(dirPath, `${fileName}.js`), `//${pagePath}.js\n${jsContent}`);

    let jsonContent = getTmp.getTemplate('wechat.json')
    fs.writeFileSync(path.join(dirPath, `${fileName}.json`), `${jsonContent}`);

    let wxmlContent = getTmp.getTemplate('wechat.wxml')
    fs.writeFileSync(path.join(dirPath, `${fileName}.wxml`), `<!--${pagePath}.wxml-->\n${wxmlContent}`);

    const appPath = currentPath + '/app.json'
    console.log('appPath:', appPath)
    if (fs.existsSync(appPath)) {
      let appContent = fs.readFileSync(appPath).toString()
      // console.log('appContent:',appContent)
      let appJson = JSON.parse(appContent)
      console.log('appJson:', appJson.pages)
      // let pagePath = ''
      // if (pagePath[0] === '/') {
      //   pagePath = pagePath.substring(1)
      // }
      // else {
      // pagePath = args.o
      // }
      // pagePath = pagePath
      // console.log('pagePath:', pagePath)
      appJson.pages.push(pagePath.substring(1))
      console.log('appJson:', appJson)
      let appStr = JSON.stringify(appJson, "", 2)
      fs.writeFileSync(appPath, appStr);

    }

  } else {
    console.log(`${fpath} 已存在`)
  }

} else {
  console.log('请在工程的根目录下输入要创建的路径,格式为 npx wxpath -o /pages/test 会生成 /pages/test/index.js')
}


function mkdirsSync(dirname) {
  if (fs.existsSync(dirname)) {
    return true;
  } else {
    if (mkdirsSync(path.dirname(dirname))) {
      fs.mkdirSync(dirname);
      return true;
    }
  }
}

==> xcxcreatepath-1.1.5.tgz: package/commands/wxpath.js <==
#!/usr/bin/env node

const path = require('path')
const fs = require('fs')
const minimist = require('minimist')
const getTmp = require('../libs/getTemplate')
const args = minimist(process.argv.slice(2))
console.log('args:', args)
if (args.o && typeof args.o == 'string') {
  let dirPath = ''

  const currentPath = path.resolve()
  if (!args.o.match('^((/[a-zA-Z0-9-_]+)+|/)$')) {
    console.log('路径输入错误 格式:/pages/list/list/')
    return;
  }
  const pagePath = args.o

  if (pagePath[0] === '/') {
    dirPath = currentPath + path.dirname(pagePath)
  } else {
    dirPath = currentPath + '/' + path.dirname(pagePath)
  }
  const fileName = path.basename(pagePath);
  console.log('fileName:', fileName)

  console.log('dirPath:', dirPath)
  if (!fs.existsSync(dirPath)) {
    mkdirsSync(dirPath) // 创建目录

    let wxssContent = getTmp.getTemplate('wechat.wxss')
    // console.log('wxssContent:', wxssContent)
    fs.writeFileSync(path.join(dirPath, `${fileName}.wxss`), `/*${pagePath}.wsss*/\n${wxssContent}`);

    let jsContent = getTmp.getTemplate('wechat.js')
    fs.writeFileSync(path.join(dirPath, `${fileName}.js`), `//${pagePath}.js\n${jsContent}`);

    let jsonContent = getTmp.getTemplate('wechat.json')
    fs.writeFileSync(path.join(dirPath, `${fileName}.json`), `${jsonContent}`);

    let wxmlContent = getTmp.getTemplate('wechat.wxml')
    fs.writeFileSync(path.join(dirPath, `${fileName}.wxml`), `<!--${pagePath}.wxml-->\n${wxmlContent}`);

    const appPath = currentPath + '/app.json'
    let reg = /\n(  )+/g
    console.log('appPath:', appPath)
    if (fs.existsSync(appPath)) {
      let appContent = fs.readFileSync(appPath,{encoding:'utf8', flag:'r'}).toString()
      // console.log('appContent:',appContent)
      // l
      appContent.replace(reg,appContent)
      let appJson = JSON.parse(appContent)
      console.log('appJson:', appJson.pages)
      // let pagePath = ''
      // if (pagePath[0] === '/') {
      //   pagePath = pagePath.substring(1)
      // }
      // else {
      // pagePath = args.o
      // }
      // pagePath = pagePath
      // console.log('pagePath:', pagePath)
      appJson.pages.push(pagePath.substring(1))
      console.log('appJson:', appJson)
      let appStr = JSON.stringify(appJson, "", 2)
      fs.writeFileSync(appPath, appStr);

    }

  } else {
    console.log(`${dirPath} 已存在`)
  }

} else {
  console.log('请在工程的根目录下输入要创建的路径,格式为 npx wxpath -o /pages/test 会生成 /pages/test/index.js')
}


function mkdirsSync(dirname) {
  if (fs.existsSync(dirname)) {
    return true;
  } else {
    if (mkdirsSync(path.dirname(dirname))) {
      fs.mkdirSync(dirname);
      return true;
    }
  }
}
